@@ -176,9 +176,9 @@ class CloudResourceManager(Base):
         request = projects.list(**params)
         return self.get_list_items(projects, request, 'projects')
 
-    def get_projects_dict(self):
+    def get_projects_dict(self, filter=None):
         """Return a dict of domain projects."""
-        google_projects = self.get_projects()
+        google_projects = self.get_projects(filter=filter)
         projects = {}
         for p in google_projects:
             pid = p['projectId']
